#!/usr/bin/env python
# coding: utf-8

# In[5]:


import tkinter as tk

# Layout constants.
MARGIN = 5
WINDOW_WID = 300
WINDOW_HGT = 200

class ImageOptionMenuApp:
    # Create and manage the tkinter interface.
    def __init__(self):
        # Make the main interface.
        self.window = tk.Tk()
        self.window.title('image_optionmenu')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry(f'{WINDOW_WID}x{WINDOW_HGT}')

        #  Make an OptionMenu.
        # Make a dictionary mapping text values to images.
        self.light_images = {
            'red'    : tk.PhotoImage(file='red_light.png'),
            'yellow' : tk.PhotoImage(file='yellow_light.png'),
            'green'  : tk.PhotoImage(file='green_light.png'),
        }

        # Make the OptionMenu.
        self.light_var = tk.StringVar(value='red')
        self.light_om = tk.OptionMenu(self.window,
            self.light_var, 'red', 'yellow', 'green',
            command=self.light_selected)
        self.light_om.configure(image=self.light_images['red'])

        # Get the underlying menu.
        menu = self.light_om['menu']

        # Add the menu item images.
        for text, image in self.light_images.items():
            menu.entryconfigure(text, image=image, compound=tk.NONE)

        self.light_om.pack(side=tk.TOP, padx=10, pady=10)
        
        # Display the window.
        self.window.focus_force()
        self.window.mainloop()

    def kill_callback(self):
        self.window.destroy()

    def light_selected(self, light_name):
        # Give the OptionMenu the correct image.
        print(f'Light: {light_name}')
        self.light_om.configure(image=self.light_images[light_name])


# In[6]:


ImageOptionMenuApp()
print('Done')


# In[ ]:




